@@ -201,8 +201,8 @@ class Calendar extends \Flake\Core\Model\Db {
             "validation" => "color",
             "popover"    => [
                     "title"   => "Calendar color",
-                    "content" => "This is the color that will be displayed in your CalDAV client.</br>" .
-                    "Must be supplied in format '#RRGGBBAA' (alpha channel optional) with hexadecimal values.</br>" .
+                    "content" => "This is the color that will be displayed in your CalDAV client.<br/>" .
+                    "Must be supplied in format '#RRGGBBAA' (alpha channel optional) with hexadecimal values.<br/>" .
                     "This value is optional.",
             ]
         ]));
