@@ -64,12 +64,6 @@ class Collection extends \Flake\Core\FLObject implements \Iterator {
         return $oRes;
     }
 
-    function &each() {
-        list($key, $val) = each($this->aCollection);
-
-        return $val;
-    }
-
     function reset() {
         reset($this->aCollection);
     }
@@ -115,6 +109,7 @@ class Collection extends \Flake\Core\FLObject implements \Iterator {
         }
 
         $var = null;    # two lines instead of one
+
         return $var;    # as PHP needs a variable to return by ref
     }
 
@@ -148,6 +143,7 @@ class Collection extends \Flake\Core\FLObject implements \Iterator {
     # This abstraction is useful because of CollectionTyped
     protected function newCollectionLikeThisOne() {
         $oCollection = new \Flake\Core\Collection();    # two lines instead of one
+
         return $oCollection;                            # as PHP needs a variable to return by ref
     }
 
